function r = readrange(infile)
%  r = readrange(infile)
% Reads a range image from the Brown Range Image Database
%
% By Kim S. Pedersen, kimstp@diku.dk, March 15, 2002

fid = fopen(infile,'r','ieee-be');

if fid == -1
  error('Could not open file')
else
  % Read image size
  Rows = fread(fid, 1,'uint16'); % Number of rows
  Cols = fread(fid, 1,'uint16'); % Number of cols

  % Read image data
  range = fread(fid, [Rows, Cols], 'uint16');       % Range data
  intensity = fread(fid, [Rows, Cols], 'uint16');   % Intensity data
  bearing = fread(fid, [Rows, Cols], 'uint16');     % Bearing
  inclination = fread(fid, [Rows, Cols], 'uint16'); % Inclination
  fclose(fid);

  r = struct('range', range, 'intensity', intensity, 'bearing', bearing, ...
	     'inclination', inclination);
end

return;
